#
# spec file for package OpenSceneGraph
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _osg_so_nr 161
%define _opt_so_nr 21
%if 0%{?is_opensuse}
%bcond_without gdal
%bcond_with    ffmpeg
%else
%bcond_with    gdal
%bcond_without ffmpeg
%endif

%bcond_without asio
%bcond_without dcmtk
%bcond_without fox
%bcond_without occt

%if 0%{?suse_version} >= 1550
%bcond_with    gtk2
%else
%bcond_without gtk2
%endif

Name:           OpenSceneGraph
Version:        3.6.5
Release:        8.7
Summary:        3D graphics toolkit
# Actually they call it OpenSceneGraph Public License, Version 0.0, which is
# "LGPL-2.1-only AND WXwindows" (https://spdx.org/licenses/WXwindows)
# "LGPL-2.1-only WITH WxWindows-exception-3.1" would be valid (https://spdx.org/licenses/WxWindows-exception-3.1.html)
# Contrary to that most sources state "GPL-2.0-only"
# Ticket opened to clear license situation: https://github.com/openscenegraph/OpenSceneGraph/issues/552
License:        LGPL-2.1-only WITH WxWindows-exception-3.1
Group:          Productivity/Graphics/Other
URL:            http://openscenegraph.org/projects/osg
Source0:        https://github.com/openscenegraph/%{name}/archive/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE - fix build with asio >= 1.14.0, https://github.com/openscenegraph/OpenSceneGraph/issues/921
Patch0:         0001-Replace-boost-bind-usage-with-std-bind.patch
Patch1:         0002-Replace-obsoleted-asio-basic_stream_socket-get_io_se.patch
# PATCH-FIX-UPSTREAM - Fix build with OCCT 7.6
Patch2:         0001-Use-non-deprecated-methods-to-access-OpenCascade-Tri.patch
BuildRequires:  cmake
BuildRequires:  curl-devel
%if %{with ffmpeg}
BuildRequires:  ffmpeg-devel
%endif
BuildRequires:  fltk-devel
BuildRequires:  freeglut-devel
BuildRequires:  gcc-c++
BuildRequires:  giflib-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  pkgconfig
BuildRequires:  unzip
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(OpenEXR)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-app-1.0)
BuildRequires:  pkgconfig(gstreamer-audio-1.0)
BuildRequires:  pkgconfig(gstreamer-base-1.0)
BuildRequires:  pkgconfig(gstreamer-fft-1.0)
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0)
BuildRequires:  pkgconfig(gstreamer-video-1.0)
%if %{with gtk2}
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(gtkglext-1.0)
%endif
BuildRequires:  pkgconfig(librsvg-2.0) >= 2.35
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libvncserver)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(poppler-glib)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(xrandr)
%if %{with dcmtk}
BuildRequires:  cmake(DCMTK)
BuildRequires:  pkgconfig(icu-uc)
%endif
%if %{with fox}
BuildRequires:  pkgconfig(fox)
%endif
%if %{with occt}
BuildRequires:  occt-devel
%endif
%if %{with asio}
BuildRequires:  asio-devel
%endif
%if %{with gdal}
BuildRequires:  pkgconfig(gdal)
%endif

%description
The OpenSceneGraph is a graphics toolkit for the development of
graphic applications such as flight simulators, games, virtual
reality and scientific visualization. Based around the concept of a
scene graph, it provides an object-oriented framework on top of
OpenGL, freeing the developer from implementing and optimizing low
level graphics calls, and provides many additional utilities for
development of graphics applications.

%package -n libOpenSceneGraph%{_osg_so_nr}
Summary:        Shared libraries for OpenSceneGraph
Group:          System/Libraries
# try to cover up past mistakes
Conflicts:      libOpenSceneGraph100
Conflicts:      libOpenSceneGraph158

%description -n libOpenSceneGraph%{_osg_so_nr}
The OpenSceneGraph is a graphics toolkit for the development of
graphic applications such as flight simulators, games, virtual
reality and scientific visualization. Based around the concept of a
scene graph, it provides an object-oriented framework on top of
OpenGL.

This package contains the shared libraries for OpenSceneGraph.

%package -n libOpenSceneGraph-devel
Summary:        OpenSceneGraph development files
Group:          Development/Libraries/C and C++
Requires:       curl-devel
Requires:       freeglut-devel
Requires:       giflib-devel
Requires:       libOpenSceneGraph%{_osg_so_nr} = %{version}-%{release}
Requires:       libOpenThreads-devel = %{version}
Requires:       libjpeg-devel
Requires:       libpng-devel
Requires:       pkgconfig(freetype2)
Requires:       pkgconfig(librsvg-2.0)
Requires:       pkgconfig(libtiff-4)
Requires:       pkgconfig(poppler-glib)
Requires:       pkgconfig(sdl2)
Requires:       pkgconfig(xrandr)
Conflicts:      libOpenSceneGraph1-devel

%description -n libOpenSceneGraph-devel
The OpenSceneGraph is a graphics toolkit for the development of
graphic applications such as flight simulators, games, virtual
reality and scientific visualization. Based around the concept of a
scene graph, it provides an object-oriented framework on top of
OpenGL.

This package contains the header and development files for
OpenSceneGraph.

%package -n libOpenThreads%{_opt_so_nr}
Summary:        Shared libraries for OpenSceneGraph
Group:          System/Libraries

%description -n libOpenThreads%{_opt_so_nr}
The OpenSceneGraph is a graphics toolkit for the development of
graphic applications such as flight simulators, games, virtual
reality and scientific visualization. Based around the concept of a
scene graph, it provides an object-oriented framework on top of
OpenGL.

This package contains the shared libraries for OpenSceneGraph.

%package -n libOpenThreads-devel
Summary:        OpenSceneGraph development files
Group:          Development/Libraries/C and C++
Requires:       libOpenThreads%{_opt_so_nr} = %{version}
Conflicts:      libOpenThreads1-devel

%description -n libOpenThreads-devel
The OpenSceneGraph is a graphics toolkit for the development of
graphic applications such as flight simulators, games, virtual
reality and scientific visualization. Based around the concept of a
scene graph, it provides an object-oriented framework on top of
OpenGL.

This package contains the header and development files for
OpenSceneGraph.

%package plugins
Summary:        Plugins for OpenSceneGraph
Group:          Productivity/Graphics/Other

%description plugins
The OpenSceneGraph is a graphics toolkit for the development of
graphic applications such as flight simulators, games, virtual
reality and scientific visualization. Based around the concept of a
scene graph, it provides an object-oriented framework on top of
OpenGL.

This package contains some plugins for OpenSceneGraph.

%package plugin-ffmpeg
Summary:        FFmpeg plugin for OpenSceneGraph
Group:          Productivity/Graphics/Other
Provides:       OpenSceneGraphPlugin(ext:mov)
Provides:       OpenSceneGraphPlugin(ext:avi)
Provides:       %{name}-plugins:%{_libdir}/osgPlugins-%{version}/osgdb_ffmpeg.so
Conflicts:      %{name}-plugins < %{version}-%{release}

%description plugin-ffmpeg
The OpenSceneGraph is a graphics toolkit for the development of
graphic applications.

This package contains the FFmpeg plugin for OpenSceneGraph.

%package plugin-gdal
Summary:        GDAL plugin for OpenSceneGraph
Group:          Productivity/Graphics/Other
Provides:       OpenSceneGraphPlugin(ext:gdal)
Provides:       %{name}-plugins:%{_libdir}/osgPlugins-%{version}/osgdb_gdal.so
Conflicts:      %{name}-plugins < %{version}-%{release}

%description plugin-gdal
The OpenSceneGraph is a graphics toolkit for the development of
graphic applications.

This package contains the GDAL plugin for OpenSceneGraph.

%package plugin-gstreamer
Summary:        GStreamer plugin for OpenSceneGraph
Group:          Productivity/Graphics/Other
Provides:       OpenSceneGraphPlugin(ext:mov)
Provides:       OpenSceneGraphPlugin(ext:avi)
Provides:       %{name}-plugins:%{_libdir}/osgPlugins-%{version}/osgdb_gstreamer.so
Conflicts:      %{name}-plugins < %{version}-%{release}

%description plugin-gstreamer
The OpenSceneGraph is a graphics toolkit for the development of
graphic applications.

This package contains the GStreamer plugin for OpenSceneGraph.

%package plugin-opencascade
Summary:        OpenCASCADE plugin for OpenSceneGraph
Group:          Productivity/Graphics/Other
Provides:       OpenSceneGraphPlugin(ext:step)
Provides:       OpenSceneGraphPlugin(ext:iges)
Provides:       %{name}-plugins:%{_libdir}/osgPlugins-%{version}/osgdb_opencascade.so
Conflicts:      %{name}-plugins < %{version}-%{release}

%description plugin-opencascade
The OpenSceneGraph is a graphics toolkit for the development of
graphic applications.

This package contains the OpenCASCADE plugin for OpenSceneGraph.

%package plugin-pdf
Summary:        PDF plugin for OpenSceneGraph
Group:          Productivity/Graphics/Other
Provides:       OpenSceneGraphPlugin(ext:pdf)
Provides:       %{name}-plugins:%{_libdir}/osgPlugins-%{version}/osgdb_pdf.so
Conflicts:      %{name}-plugins < %{version}-%{release}

%description plugin-pdf
The OpenSceneGraph is a graphics toolkit for the development of
graphic applications.

This package contains the Poppler based PDF plugin for OpenSceneGraph.

%package examples
Summary:        OpenSceneGraph example applications
Group:          Productivity/Graphics/Other

%description examples
The OpenSceneGraph is a graphics toolkit for the development of
graphic applications such as flight simulators, games, virtual
reality and scientific visualization. Based around the concept of a
scene graph, it provides an object-oriented framework on top of
OpenGL.

This package contains some example applications built with OpenSceneGraph

%prep
%setup -q -n %{name}-%{name}-%{version}
%if 0%{?suse_version} >= 1550 || 0%{?sle_version} >= 150400
%patch0 -p1
%patch1 -p1
%endif
%patch2 -p1

for file in *.md *.txt; do
	sed -i "s/\r//g" "$file"
done
chmod 644 *.md *.txt

%build
%cmake \
  -DCMAKE_RELWITHDEBINFO_POSTFIX="" \
  -DBUILD_OSG_EXAMPLES=ON \
  -DBUILD_OSG_PLUGINS=ON \
  -DBUILD_DOCUMENTATION=OFF \
  -DBUILD_OSG_APPLICATIONS=ON \
  -DDYNAMIC_OPENSCENEGRAPH=ON \
  -DDYNAMIC_OPENTHREADS=ON \
%if "%{_lib}" == "lib64"
  -DLIB_POSTFIX=64
%endif

%cmake_build

%install
%cmake_install
# example bins installed in share dir, not acceptable. Note, this will break
# when %%{_datadir}/OpenSceneGraph is also used for other stuff
mv %{buildroot}%{_datadir}/OpenSceneGraph \
   %{buildroot}%{_libdir}

%post -n libOpenSceneGraph%{_osg_so_nr} -p /sbin/ldconfig
%post -n libOpenThreads%{_opt_so_nr} -p /sbin/ldconfig
%postun -n libOpenSceneGraph%{_osg_so_nr} -p /sbin/ldconfig
%postun -n libOpenThreads%{_opt_so_nr} -p /sbin/ldconfig

%files
%license LICENSE.txt
%doc AUTHORS.txt NEWS.txt README.md
%{_bindir}/osg2cpp
%{_bindir}/osgarchive
%{_bindir}/osgconv
%{_bindir}/osgfilecache
%{_bindir}/osgversion
%{_bindir}/osgviewer
%{_bindir}/present3D
%{_bindir}/osgshaderpipeline

%files plugins
%{_libdir}/osgPlugins-%{version}/*.so
%exclude %{_libdir}/osgPlugins-%{version}/osgdb_ffmpeg*.so
%exclude %{_libdir}/osgPlugins-%{version}/osgdb_gdal*.so
%exclude %{_libdir}/osgPlugins-%{version}/osgdb_gstreamer*.so
%exclude %{_libdir}/osgPlugins-%{version}/osgdb_opencascade*.so
%exclude %{_libdir}/osgPlugins-%{version}/osgdb_ogr*.so
%exclude %{_libdir}/osgPlugins-%{version}/osgdb_pdf*.so

%if %{with ffmpeg}
%files plugin-ffmpeg
%{_libdir}/osgPlugins-%{version}/osgdb_ffmpeg*.so
%endif

%if %{with gdal}
%files plugin-gdal
%{_libdir}/osgPlugins-%{version}/osgdb_gdal*.so
%{_libdir}/osgPlugins-%{version}/osgdb_ogr*.so
%endif

%files plugin-gstreamer
%{_libdir}/osgPlugins-%{version}/osgdb_gstreamer*.so

%files plugin-opencascade
%{_libdir}/osgPlugins-%{version}/osgdb_opencascade*.so

%files plugin-pdf
%{_libdir}/osgPlugins-%{version}/osgdb_pdf*.so

%files -n libOpenSceneGraph%{_osg_so_nr}
%{_libdir}/libosg.so.*
%{_libdir}/libosgAnimation.so.*
%{_libdir}/libosgDB.so.*
%{_libdir}/libosgFX.so.*
%{_libdir}/libosgGA.so.*
%{_libdir}/libosgManipulator.so.*
%{_libdir}/libosgParticle.so.*
%{_libdir}/libosgShadow.so.*
%{_libdir}/libosgSim.so.*
%{_libdir}/libosgTerrain.so.*
%{_libdir}/libosgText.so.*
%{_libdir}/libosgUtil.so.*
%{_libdir}/libosgUI.so.*
%{_libdir}/libosgVolume.so.*
%{_libdir}/libosgViewer.so.*
%{_libdir}/libosgWidget.so.*
%{_libdir}/libosgPresentation.so.*
%dir %{_libdir}/osgPlugins-%{version}/

%files -n libOpenSceneGraph-devel
%{_includedir}/osg/
%{_includedir}/osgAnimation/
%{_includedir}/osgDB/
%{_includedir}/osgFX/
%{_includedir}/osgGA/
%{_includedir}/osgManipulator/
%{_includedir}/osgParticle/
%{_includedir}/osgShadow/
%{_includedir}/osgSim/
%{_includedir}/osgTerrain/
%{_includedir}/osgText/
%{_includedir}/osgUI/
%{_includedir}/osgUtil/
%{_includedir}/osgViewer/
%{_includedir}/osgVolume/
%{_includedir}/osgWidget/
%{_includedir}/osgPresentation/
%{_libdir}/libosg.so
%{_libdir}/libosgAnimation.so
%{_libdir}/libosgDB.so
%{_libdir}/libosgFX.so
%{_libdir}/libosgGA.so
%{_libdir}/libosgManipulator.so
%{_libdir}/libosgParticle.so
%{_libdir}/libosgShadow.so
%{_libdir}/libosgSim.so
%{_libdir}/libosgTerrain.so
%{_libdir}/libosgText.so
%{_libdir}/libosgUI.so
%{_libdir}/libosgUtil.so
%{_libdir}/libosgViewer.so
%{_libdir}/libosgVolume.so
%{_libdir}/libosgWidget.so
%{_libdir}/libosgPresentation.so
%{_libdir}/pkgconfig/openscenegraph.pc
%{_libdir}/pkgconfig/openscenegraph-osg*.pc

%files examples
%{_libdir}/OpenSceneGraph

%files -n libOpenThreads%{_opt_so_nr}
%{_libdir}/libOpenThreads.so.*

%files -n libOpenThreads-devel
%{_includedir}/OpenThreads/
%{_libdir}/libOpenThreads.so
%{_libdir}/pkgconfig/openthreads.pc

%changelog
* Thu Dec  1 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Split several plugins with significant dependencies from main
  plugins package.
- Disable FFmpeg plugin on TW until compatibility issues are
  resolved.
* Mon Jul  4 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build with OpenCASCADE 7.6, add
  0001-Use-non-deprecated-methods-to-access-OpenCascade-Tri.patch
* Thu Apr 28 2022 Jan Engelhardt <jengelh@inai.de>
- Resolve rpmlint report "libOpenSceneGraph158.x86_64: E:
  shlib-policy-name-error SONAME: libosg.so.161, expected package
  suffix: 161"
* Tue Aug 10 2021 pgajdos@suse.com
- fix build with openexr3: remove redundant BuildRequires (pkgconfig(IlmBase))
* Sat Jun 19 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build on TW with asio 1.18.x, add
  0001-Replace-boost-bind-usage-with-std-bind.patch and
  0002-Replace-obsoleted-asio-basic_stream_socket-get_io_se.patch
- Disable GTK2 example on TW
- Disable wxWidgets example
- Do not package huge ChangeLog (commit log)
* Fri Jul 31 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Put back PowerPC specific constraints (from 6 to 7GB disk space)
  as failing on some builders.
* Fri Apr  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add more optional build dependencies.
* Fri Mar 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 3.6.5. Check the ChangeLog file for the list of changes.
- Drop fix_deprecated_FIND_PACKAGE_wxWidgets_usage.patch. Merged
  upstream.
* Mon Feb  3 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Replace wrong Requires: SDL-devel in devel package with
  pkgconfig(sdl2).
- Remove architecture specific _constraints, there are no significant
  differences in real life, avoids failures for other architectures
  not covered.
* Fri Dec 13 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update _constraints for ARM
* Tue Dec 10 2019 Michael Vetter <mvetter@suse.com>
- bsc#1158895: Remove dependency on jasper (due to planned removal)
  Removes JPEG2000 support.
* Mon Sep 30 2019 Michel Normand <normand@linux.vnet.ibm.com>
- Add _constraints for PowerPC to avoid linker failure
* Tue Jul  2 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix failing builds with CMake 3.14 and later
  Add fix_deprecated_FIND_PACKAGE_wxWidgets_usage.patch
* Sun Mar 24 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Add conflicts for the legacy libOpenSceneGraph1-devel and
  libOpenThreads1-devel packages, which install into the same location.
* Wed Oct 10 2018 Ondřej Súkup <mimi.vx@gmail.com>
- update to 3.6.3
  * big bunch of fixes for performance and compatibility
  * fixes for crashes
  * for details see Changelog
* Thu Jul 12 2018 mimi.vx@gmail.com
- update to 3.6.2
  * Removed deprecated xine plugin to simplify licensing
  * big bunch of fixes for performance and compatibility
  * for details see Changelog
* Tue May 29 2018 mimi.vx@gmail.com
- update to bugfix release 3.6.1
  * big bunch of fixes for performance and compatibility
  * for details see Changelog
* Tue Apr 17 2018 mimi.vx@gmail.com
- update to 3.6.0
- drop 8e26ebd23ef9_Fixed_coverity_detected_defect_OOB_read.patch
- drop 01c712e85195_Explicit_signed_char_declarations.patch
  * OpenThreads::Affinity introduced to enable setting of processor affinity
    on viewer and database threads
  * osgText rewritten to improve visual quality, add signed distance field
    support and full GLES2/3 and GL3/4 support
  * Added VertexArrayObject support, enable full OpenGL Core Profile support
  * Added OpenCASCADE plugin
  * Added STEP (.stp) plugin
  * Improvements to FBX and COLLADA loaders
  * Improvements to gles plugin to provide better Sketchfab support
  * Added osgemscripten example
  * Improvements to osgAnimation
  * NodeVisitor ValueMap for storing values that can be stored and accessed
    across frames, such as update, event and cull traversals
  * ShapeDrawable rewritten as an osg::Geometry to improve performance and flexibility
  * Added osg::MultiDrawArrays support
  * Added osgdeferred example that illustrates how to implement deferred rendering
  * Added MultiDrawIndirect support
  * Moved glDispatchCompute control out of osg::Program into a dedicated
    osg::DispatchCompute class to improve control of compute shaders
  * KdTree support added for PolytopeIntersector, and ability to work with
    points, lines and polygons
  * osgQt has been moved out to it's own dedicated osgQt github repository
  * CMake build support for iOS bitcode builds
  * CoverityScan testing introduced, fixes bring defect density to 0.0
    per 1,0000 lines of code!
* Wed Feb 14 2018 mimi.vx@gmail.com 
- update to 3.4.1
  * Improves to GLES support across platforms
  * Full support for osgText and on screen stats across all platfroms
  * Build fixes to allow compilation against recent
    3rd party depdendency changes
  * Range of runtime fixes
* Fri Dec 15 2017 crrodriguez@opensuse.org
- Switch to QT5, as QT4 is dead.
- Remove manual requires on -devel package.
* Sat Aug 19 2017 stefan.bruens@rwth-aachen.de
- Add 8e26ebd23ef9_Fixed_coverity_detected_defect_OOB_read.patch
  Fix out-of-bound-read, also required for the next patch to apply
- Add 01c712e85195_Explicit_signed_char_declarations.patch
  Fix compilation on architectures where char is unsigned
* Sat Feb  4 2017 jengelh@inai.de
- Trim description
* Tue Aug 23 2016 rpm@fthiessen.de
- Fixed source url, required for factory submission
* Sun Jul 31 2016 jengelh@inai.de
- Rectify shared library package name
* Sat May 21 2016 rpm@fthiessen.de
- Fixed BuildRequires (libjasper, and gdal).
* Tue Nov 24 2015 rpm@fthiessen.de
- Update to 3.4.0
- Removed OpenSceneGraph-gcc43.patch, not more needed
- Removed OpenSceneGraph-libgif6.patch, fixed upstream
* Wed Nov 18 2015 Rene.vanPaassen@gmail.com
- Removed OpenSceneGraph-giflib.patch, patched upstream
* Tue Nov 17 2015 Rene.vanPaassen@gmail.com
- Update to 3.2.3
- fixes building osgearth 2.7.0
* Wed Feb 11 2015 mpluskal@suse.com
- Update to 3.2.1:
  * no changelog provided by upstream
- Fix building with recent giflib (OpenSceneGraph-giflib.patch)
* Tue Jan  7 2014 bruno@ioda-net.ch
- update to 3.2.0 stable release
  see http://svn.openscenegraph.org/osg/OpenSceneGraph/tags/OpenSceneGraph-3.2.1-rc1/ChangeLog
- updated _opt_so_nr from 12 to 13
- packaging
  make verbose 1
  use C(XX)_FLAGS_RELEASE for applying optflags correctly
  fix some rpmlint warnings
- removed patches:
  * OpenSceneGraph-xine12.patch : merged upstream
- modified patches:
  * OpenSceneGraph-libgif6.patch : partially merged upstream
    First part redone against 3.2.0
* Thu Oct  3 2013 seife+obs@b1-systems.com
- libOpenThreads-devel does not have a huge dependency
* Wed Apr  3 2013 joop.boonen@opensuse.org
- Created OpenSceneGraph-libgif6.patch
  Used Raymond Wooninck kdelibs patch as a template
  https://git.reviewboard.kde.org/r/109478/
* Sun Sep  2 2012 thorstenb@flightgear.org
- Dropped gtk-glext install dependency for openSUSE factory
* Sun Sep  2 2012 thorstenb@flightgear.org
- Dropped gtk-glext dependency for openSUSE factory
- Removed obsolete openSUSE versions from spec file
* Mon Jul  2 2012 thorstenb@flightgear.org
- Patch to compile with libxine >= 1.2.0
* Sun Feb 19 2012 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Kill build-time dependency on XUL; it is nowhere referenced
- Remove illegal Obsoletes/Provides (see shlib pol.)
- Ensure pkgconfig symbols are generated
* Thu Sep  1 2011 highwaystar.ru@gmail.com
- update to 3.0.1
* Sat Jul  2 2011 jengelh@medozas.de
- Use %%_smp_mflags for parallel building
- Strip %%clean section (not needed on BS)
* Tue Apr 13 2010 toni@links2linux.de
- update to 2.8.3
- added docs
- added ffmpeg based plugins
- added gdal based plugins
- split-off viewers (FLTK, QT, SDL, WX) to keep dependencies smaller
- new sonames ==> libOpenSceneGraph65
* Tue Oct 27 2009 toni@links2linux.de
- update to 2.8.2
* Thu May 21 2009 toni@links2linux.de
- update to 2.8.1
* Fri Feb 13 2009 toni@links2linux.de
- update to 2.8.0
- new sonames ==> libOpenSceneGraph55
* Tue Oct  7 2008 toni@links2linux.de
- update to 2.6.1
- new sonames ==> libOpenSceneGraph48
* Fri Aug  8 2008 toni@links2linux.de
- update to 2.6.0
- new sonames ==> libOpenThreads11, libOpenSceneGraph44
* Mon May 12 2008 toni@links2linux.de
- update to 2.4.0
- new sonames ==> libOpenThreads10, libOpenSceneGraph35
* Sat Feb  2 2008 toni@links2linux.de
- initial version 2.2
